==> geojson_stats-0.2.6-py3-none-any.whl: geojson_stats/html.py <==
from .models import TotalStats
from string import Template
import re

TPL_VAR_PATTERN = r'\$\{([a-zA-Z0-9_]+(?:\_[a-zA-Z0-9_]+)*)\}'

def get_val(d, k):
    keys = k.split('_')
    for key in keys:
        if key.isdigit():
            if key == keys[-1]:
                try:
                    return list(d.keys())[int(key)]
                except:
                    return "-"
            else:
                try:
                    d = d[list(d.keys())[int(key)]]
                except:
                    return "-"
        elif isinstance(d, dict) and key in d:
            d = d[key]
        else:
            return None
    if key == "percent":
        return "{d}%".format(d=d)
    return d

# Create HTML reports with stats
class Html:

    tpl: str = ""
    stats: TotalStats
    extra: dict = None

    def __init__(self, tpl_file: str, stats: TotalStats, extra_params = dict):
        self.tpl_file = tpl_file
        self.stats = stats.dict()
        self.extra_params = extra_params

        with open(tpl_file, 'r') as tpl_html:
            self.tpl = tpl_html.read()

    def build(self):
        matches = re.findall(TPL_VAR_PATTERN, self.tpl)
        replacements = {}
        for match in matches:
            value = get_val(self.stats, match)
            if isinstance(value, float):
                value = round(value, 2)
            replacements[match] = value
            
            if match in self.extra_params:
                replacements[match] = self.extra_params.get(match)
        
        template = Template(self.tpl)
        return template.substitute(replacements)

    def dump(self):
        print(self.build())

==> geojson_stats-0.2.9-py3-none-any.whl: geojson_stats/html.py <==
from .models import TotalStats
from string import Template
import re

TPL_VAR_PATTERN = r'\$\{([a-zA-Z0-9_]+(?:\_[a-zA-Z0-9_]+)*)\}'

def get_val(d, k):
    keys = k.split('_')
    for key in keys:
        if key.isdigit():
            if key == keys[-1]:
                try:
                    return list(d.keys())[int(key)]
                except:
                    return "-"
            else:
                try:
                    d = d[list(d.keys())[int(key)]]
                except:
                    return "-"
        elif isinstance(d, dict) and key in d:
            d = d[key]
        else:
            return "-"
    if key == "percent":
        return "{d}%".format(d=d)
    return d

# Create HTML reports with stats
class Html:

    tpl: str = ""
    stats: TotalStats
    extra: dict = None

    def __init__(self, tpl_file: str, stats: TotalStats, extra_params: dict = {}):
        self.tpl_file = tpl_file
        self.stats = stats.dict()
        self.extra_params = extra_params

        with open(tpl_file, 'r') as tpl_html:
            self.tpl = tpl_html.read()

    def build(self):
        matches = re.findall(TPL_VAR_PATTERN, self.tpl)
        replacements = {}
        for match in matches:
            value = get_val(self.stats, match)
            if isinstance(value, float):
                value = round(value, 2)
            replacements[match] = value
            
            if match in self.extra_params:
                replacements[match] = self.extra_params.get(match)

        template = Template(self.tpl)
        return template.substitute(replacements)

    def dump(self):
        print(self.build())
